#!/usr/bin/python3
from PyQt6 import QtWidgets
from QTermWidget import QTermWidget


class Terminal(QTermWidget):
    def __init__(self, process: str, args: list):
        super().__init__(0)
        self.finished.connect(self.close)
        self.setTerminalSizeHint(False)
        self.setColorScheme("DarkPastels")
        self.setShellProgram(process)
        self.setArgs(args)
        self.startShellProgram()
        self.show()


if __name__ == "__main__":
    app = QtWidgets.QApplication([])
    args = ["--clean", "--noplugin"]
    term = Terminal("vim", args)
    app.exec()



from pyqtbuild import PyQtBindings, PyQtProject

class QTermWidget(PyQtProject):
    def __init__(self):
        super().__init__()
        self.bindings_factories = [QTermWidgetBindings]

class QTermWidgetBindings(PyQtBindings):
    def __init__(self, project):
        super().__init__(project, name='QTermWidget', sip_file='qtermwidget.sip', qmake_QT=['widgets'])
        self._project = project

    def apply_user_defaults(self, tool):
        self.libraries.append('qtermwidget6')
        super().apply_user_defaults(tool)
